@@ -1,16 +1,13 @@
-"""
-Copyright (C) 2021 Clariteia SL
+"""minos.networks.brokers.services module."""
 
-This file is part of minos framework.
-
-Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
-"""
 from __future__ import (
     annotations,
 )
 
-from aiomisc.service.periodic import (
-    PeriodicService,
+import logging
+
+from aiomisc import (
+    Service,
 )
 from cached_property import (
     cached_property,
@@ -20,9 +17,11 @@ from .producers import (
     Producer,
 )
 
+logger = logging.getLogger(__name__)
 
-class ProducerService(PeriodicService):
-    """Minos QueueDispatcherService class."""
+
+class ProducerService(Service):
+    """ProducerService class."""
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -34,14 +33,13 @@ class ProducerService(PeriodicService):
         :return: This method does not return anything.
         """
         await self.dispatcher.setup()
-        await super().start()
 
-    async def callback(self) -> None:
-        """Method to be called periodically by the internal ``aiomisc`` logic.
+        try:
+            self.start_event.set()
+        except RuntimeError:
+            logger.warning("Runtime is not properly setup.")
 
-        :return:This method does not return anything.
-        """
-        await self.dispatcher.dispatch()
+        await self.dispatcher.dispatch_forever()
 
     async def stop(self, err: Exception = None) -> None:
         """Stop the service execution.
@@ -49,7 +47,6 @@ class ProducerService(PeriodicService):
         :param err: Optional exception that stopped the execution.
         :return: This method does not return anything.
         """
-        await super().stop(err)
         await self.dispatcher.destroy()
 
     @cached_property
