@@ -1,17 +1,11 @@
-"""
-Copyright (C) 2021 Clariteia SL
+"""minos.networks.handlers.abc.setups module."""
 
-This file is part of minos framework.
-
-Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
-"""
 from typing import (
     NoReturn,
 )
 
 from psycopg2.sql import (
     SQL,
-    Identifier,
 )
 
 from minos.common import (
@@ -22,8 +16,6 @@ from minos.common import (
 class HandlerSetup(PostgreSqlMinosDatabase):
     """Minos Broker Setup Class"""
 
-    TABLE_NAME: str
-
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -32,7 +24,7 @@ class HandlerSetup(PostgreSqlMinosDatabase):
 
     async def _create_event_queue_table(self) -> NoReturn:
         _CREATE_TABLE_QUERY = SQL(
-            "CREATE TABLE IF NOT EXISTS {} ("
+            "CREATE TABLE IF NOT EXISTS consumer_queue ("
             '"id" BIGSERIAL NOT NULL PRIMARY KEY, '
             '"topic" VARCHAR(255) NOT NULL, '
             '"partition_id" INTEGER,'
@@ -40,4 +32,4 @@ class HandlerSetup(PostgreSqlMinosDatabase):
             '"retry" INTEGER NOT NULL DEFAULT 0,'
             '"creation_date" TIMESTAMP NOT NULL)'
         )
-        await self.submit_query(_CREATE_TABLE_QUERY.format(Identifier(self.TABLE_NAME)), lock=hash(self.TABLE_NAME))
+        await self.submit_query(_CREATE_TABLE_QUERY, lock=hash("consumer_queue"))
