@@ -6,13 +6,9 @@ This file is part of minos framework.
 Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
 """
 
-from .consumers import (
-    CommandReplyConsumer,
-)
 from .handlers import (
     CommandReplyHandler,
 )
 from .services import (
-    CommandReplyConsumerService,
     CommandReplyHandlerService,
 )
